#
# spec file for package python-hyperframe
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define skip_python2 1
%{?sle15_python_module_pythons}
Name:           python-hyperframe
Version:        6.0.1
Release:        2.3
Summary:        HTTP/2 framing layer for Python
License:        MIT
URL:            https://github.com/python-hyper/hyperframe
Source0:        https://files.pythonhosted.org/packages/source/h/hyperframe/hyperframe-%{version}.tar.gz
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
This library contains the HTTP/2 framing code used in the hyper project.
It provides a pure-Python codebase that is capable of decoding a binary
stream into HTTP/2 frames.

%prep
%setup -q -n hyperframe-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%license LICENSE
%doc README.rst CONTRIBUTORS.rst CHANGELOG.rst
%{python_sitelib}/hyperframe
%{python_sitelib}/hyperframe-%{version}-py%{python_version}.egg-info

%changelog
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Wed Apr 21 2021 Dirk Müller <dmueller@suse.com>
- update to 6.0.1:
  - Added support for Python 3.9.
  - Added type hints.
* Mon Sep 14 2020 Steve Kowalik <steven.kowalik@suse.com>
- Update to 6.0.0:
  * API Changes (Backward-incompatible)
    + Introduce ``HyperframeError`` base exception class for all errors
    raised within hyperframe.
    + Change exception base class of ``UnknownFrameError`` to
    ``HyperframeError``
    + Change exception base class of ``InvalidPaddingError`` to
    ``HyperframeError``
    + Change exception base class of ``InvalidFrameError`` to
    ``HyperframeError``
    + Invalid frames with wrong stream id (zero vs. non-zero) now raise
    ``InvalidDataError``.
    + Invalid SETTINGS frames (non-empty but ACK) now raise
    ``InvalidDataError``.
    + Invalid ALTSVC frames with non-bytestring field or origin now raise
    ``InvalidDataError``.
  * API Changes (Backward-compatible)
    + Deprecate ``total_padding`` - use `pad_length` instead.
    + Improve repr() output for all frame classes.
    + Introduce Frame.explain(data) for quick introspection of raw data.
  * Bugfixes
    + Fixed padding parsing for ``PushPromiseFrame``.
    + Fixed unchecked frame length for ``PriorityFrame``. It now correctly
    raises ``InvalidFrameError``.
    + Fixed promised stream id validation for ``PushPromiseFrame``. It now
    raises ``InvalidDataError``.
    + Fixed unchecked frame length for ``WindowUpdateFrame``. It now correctly
    raises ``InvalidFrameError``.
    + Fixed window increment value range validation. It now raises
    ``InvalidDataError``.
    + Fixed parsing of ``SettingsFrame`` with mutual exclusion of ACK flag and
    payload.
  * Other Changes
    + Removed support for Python 2.7, 3.4, 3.5, pypy.
    + Added support for Python 3.8.
* Tue Mar 26 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 5.2.0:
  * Add a new ENABLE_CONNECT_PROTOCOL settings paramter.
  * Fix collections.abc deprecation.
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Sun Feb 25 2018 aloisio@gmx.com
- Update to version 5.1.0
  API Changes (Backward-compatible)**
  * Added support for ``DataFrame.data`` being a ``memoryview``
    object.
* Sat Apr 22 2017 aloisio@gmx.com
- Update to version 5.0.0
  Backwards Incompatible API Changes:
  * Added support for unknown extension frames. These will be
    returned in the new ExtensionFrame object. The flag information
    for these frames is persisted in flag_byte if needed.
- Enabled tests
- Fixed source URL
* Mon Mar  6 2017 aloisio@gmx.com
- Update to version 4.0.2
  * Fixed AltSvc stream association, which was incorrectly set
    to ``'both'``: should have been ``'either'``.
  * Fixed a bug where stream IDs on received frames were
    allowed to be 32-bit, instead of 31-bit.
  * Fixed a bug with frames that had the ``PADDING`` flag set
    but zero-length padding, whose flow-controlled length was
    calculated wrongly.
  * Miscellaneous performance improvements to serialization
    and parsing logic.
- Converted to single-spec
* Thu Feb  2 2017 aloisio@gmx.com
- Initial package (4.0.1)
